timeintervaltools.all_intervals_are_nonoverlapping
==================================================

.. autofunction:: abjad.tools.timeintervaltools.all_intervals_are_nonoverlapping.all_intervals_are_nonoverlapping
